SuperInteractiveTextPreview class

Widget that displays text with clickable links, emails, phone numbers, and usernames

Inheritance

Constructors

SuperInteractiveTextPreview({Key? key, String? text, List<SuperInteractiveTextData>? parsedText, TextStyle? normalTextStyle, TextStyle? linkTextStyle, TextStyle? emailTextStyle, TextStyle? phoneTextStyle, TextStyle? usernameTextStyle, TextStyle? socialMediaTextStyle, TextStyle? hashtagTextStyle, TextStyle? routeTextStyle, void onLinkTap(LinkTextData linkTextData)?, void onEmailTap(EmailTextData emailTextData)?, void onPhoneTap(PhoneNumberTextData phoneNumberTextData)?, void onUsernameTap(UsernameTextData usernameTextData)?, void onSocialMediaTap(SocialMediaTextData socialMediaTextData)?, void onHashtagTap(HashtagTextData hashtagTextData)?, void onRouteTap(RouteTextData routeTextData)?, int? maxLines, TextOverflow? overflow, TextAlign? textAlign, SuperInteractiveTextPreviewTheme? textPreviewTheme})
const
SuperInteractiveTextPreview.builder({Key? key, String? text, List<SuperInteractiveTextData>? parsedText, void onLinkTap(LinkTextData linkTextData)?, void onEmailTap(EmailTextData emailTextData)?, void onPhoneTap(PhoneNumberTextData phoneNumberTextData)?, void onUsernameTap(UsernameTextData usernameTextData)?, void onSocialMediaTap(SocialMediaTextData socialMediaTextData)?, void onRouteTap(RouteTextData routeTextData)?, int? maxLines, TextOverflow? overflow, TextAlign? textAlign, Widget? textBuilder(NormalTextData normalTextData)?, Widget? linkBuilder(LinkTextData linkTextData)?, Widget? emailBuilder(EmailTextData emailTextData)?, Widget? phoneBuilder(PhoneNumberTextData phoneNumberTextData)?, Widget? usernameBuilder(UsernameTextData usernameTextData)?, Widget? socialMediaBuilder(SocialMediaTextData socialMediaTextData)?, Widget? hashtagBuilder(HashtagTextData hashtagTextData)?, Widget? routeBuilder(RouteTextData routeTextData)?, void onHashtagTap(HashtagTextData hashtagTextData)?, TextStyle? normalTextStyle, TextStyle? linkTextStyle, TextStyle? emailTextStyle, TextStyle? phoneTextStyle, TextStyle? usernameTextStyle, TextStyle? socialMediaTextStyle, TextStyle? hashtagTextStyle, TextStyle? routeTextStyle, SuperInteractiveTextPreviewTheme? textPreviewTheme})
Builder constructor for custom widget building
const

Properties

emailBuilder Widget? Function(EmailTextData emailTextData)?
final
emailTextStyle TextStyle?
final
hashCode int
The hash code for this object.
no setterinherited
hashtagBuilder Widget? Function(HashtagTextData hashtagTextData)?
final
hashtagTextStyle TextStyle?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
linkBuilder Widget? Function(LinkTextData linkTextData)?
final
linkTextStyle TextStyle?
final
maxLines int?
final
normalTextStyle TextStyle?
final
onEmailTap → void Function(EmailTextData emailTextData)?
final
onHashtagTap → void Function(HashtagTextData hashtagTextData)?
final
onLinkTap → void Function(LinkTextData linkTextData)?
final
onPhoneTap → void Function(PhoneNumberTextData phoneNumberTextData)?
final
onRouteTap → void Function(RouteTextData routeTextData)?
final
onSocialMediaTap → void Function(SocialMediaTextData socialMediaTextData)?
final
onUsernameTap → void Function(UsernameTextData usernameTextData)?
final
overflow TextOverflow?
final
parsedText List<SuperInteractiveTextData>?
final
phoneBuilder Widget? Function(PhoneNumberTextData phoneNumberTextData)?
final
phoneTextStyle TextStyle?
final
routeBuilder Widget? Function(RouteTextData routeTextData)?
final
routeTextStyle TextStyle?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
socialMediaBuilder Widget? Function(SocialMediaTextData socialMediaTextData)?
final
socialMediaTextStyle TextStyle?
final
text String?
final
textAlign TextAlign?
final
textBuilder Widget? Function(NormalTextData normalTextData)?
final
textPreviewTheme SuperInteractiveTextPreviewTheme?
final
usernameBuilder Widget? Function(UsernameTextData usernameTextData)?
final
usernameTextStyle TextStyle?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited