UsernameTextData class

Username text (starting with @)

Inheritance

Constructors

UsernameTextData({required String text})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
finalinherited
textType SuperInteractiveTextType
finalinherited
userId String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Convert SuperInteractiveTextData to Map
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited