SocialMediaTextData class
Social media link text
- Inheritance
-
- Object
- SuperInteractiveTextData
- SocialMediaTextData
Constructors
- SocialMediaTextData({required String text, required SocialMediaType type, required String url})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
finalinherited
- textType → SuperInteractiveTextType
-
finalinherited
- type → SocialMediaType
-
final
- url → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
Convert SuperInteractiveTextData to Map
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited